@@ -3,7 +3,6 @@ import matplotlib.pyplot as plt
 import numpy as np
 import plotly.graph_objects as go
 from tqdm import tqdm
-from dtw import dtw
 import pandas as pd
 
 from quick_pp.utils import power_law_func, inv_power_law_func
@@ -202,6 +201,25 @@ def skelt_harrison_xplot(sw, pc, gw, ghc, a, b, c, d, core_group=None, label=Non
 
 
 def skelt_harrison_func(h, a, b, c, d):
+    """Calculate water saturation using the Skelt-Harrison model.
+
+    This function models the relationship between water saturation and the height
+    above the free water level using an exponential decay function.
+
+    Args:
+        h (float or np.array): Height above free water level (ft).
+        a (float): A constant related to irreducible water saturation (Swirr).
+                   It influences the maximum water saturation.
+        b (float): A constant related to the height above free water level (HAFWL).
+                   It controls the rate of saturation change with height.
+        c (float): A constant related to the pore throat size distribution (PTSD).
+                   It affects the shape of the saturation curve.
+        d (float): A constant related to the entry pressure. It shifts the curve
+                   along the height axis.
+
+    Returns:
+        float or np.array: The calculated water saturation (fraction).
+    """
     return 1 - a * np.exp(-(b / (h + d))**c)
 
 
@@ -277,21 +295,6 @@ def leverett_j(pc, ift, theta, perm, phit):
     return 0.21665 * pc / (ift * abs(np.cos(np.radians(theta)))) * (perm / phit)**(0.5)
 
 
-def pseudo_leverett_j():
-    """TODO: Generate Pseudo-Leverett J based.
-
-    Args:
-        pc (float): Capillary pressure.
-        ift (float): Interfacial tension.
-        perm (float): Permeability.
-        phit (float): Total porosity.
-
-    Returns:
-        float: Pseudo-Leverett J function.
-    """
-    pass
-
-
 def sw_skelt_harrison(depth, fwl, a, b, c, d):
     """Estimate water saturation based on Skelt-Harrison.
 
@@ -306,10 +309,26 @@ def sw_skelt_harrison(depth, fwl, a, b, c, d):
     Returns:
         float: Water saturation.
     """
-    h = fwl - depth
+    h = (fwl - depth).clip(0)
     return skelt_harrison_func(h, a, b, c, d)
 
 
+def sw_lambda(phit, h, a, b, lamda):
+    """Estimate water saturation based on Lambda model (Thomeer-type Hyperbolic).
+
+    Args:
+        phit (float): Total porosity in fraction.
+        h (float): Height above free water level.
+        a (float): A constant from the best-fit curve.
+        b (float): B constant from the best-fit curve.
+        lamda (float): Lambda constant from the best-fit curve, related to pore size distribution.
+
+    Returns:
+        float: Water saturation.
+    """
+    return (a / (h * phit**b))**(1 / lamda)
+
+
 def sw_cuddy(phit, h, a, b):
     """Estimate water saturation based on Cuddy's.
 
@@ -317,13 +336,13 @@ def sw_cuddy(phit, h, a, b):
         sw (float): Water saturation (frac).
         phit (float): Total porosity (frac).
         h (float): True vertical depth.
-        a (float): Cementation exponent.
-        b (float): Saturation exponent.
+        a (float): Fitting parameter.
+        b (float): Fitting parameter (negative value).
 
     Returns:
         float: Water saturation.
     """
-    return a / phit * h**b
+    return a / (h**b * phit)
 
 
 def sw_shf_leverett_j(perm, phit, depth, fwl, ift, theta, gw, ghc, a, b, phie=None):
@@ -336,8 +355,8 @@ def sw_shf_leverett_j(perm, phit, depth, fwl, ift, theta, gw, ghc, a, b, phie=No
         fwl (float): Free water level in true vertical depth (ft).
         ift (float): Interfacial tension (dynes/cm).
         theta (float): Wetting angle (degree).
-        gw (float): Gas density (g/cc).
-        ghc (float): Gas height (g/cc).
+        gw (float): Water density (g/cc).
+        ghc (float): Hydrocarbon density (g/cc).
         a (float): A constant from J function.
         b (float): B constant from J function.
         phie (float): Effective porosity (frac), required for clay bound water calculation. Defaults to None.
@@ -345,7 +364,7 @@ def sw_shf_leverett_j(perm, phit, depth, fwl, ift, theta, gw, ghc, a, b, phie=No
     Returns:
         float: Water saturation from saturation height function.
     """
-    h = fwl - depth
+    h = (fwl - depth).clip(0)
     pc = h * (gw - ghc) * .433  # Convert g/cc to psi/ft
     shf = (a / leverett_j(pc, ift, theta, perm, phit))**(1 / b)
     return shf if not phie else shf * (1 - (phie / phit)) + (phie / phit)
@@ -358,16 +377,16 @@ def sw_shf_cuddy(phit, depth, fwl, gw, ghc, a, b):
         phit (float): Porosity (frac).
         depth (float): True vertical depth (ft).
         fwl (float): Free water level in true vertical depth (ft).
-        gw (float): Gas density (g/cc).
-        ghc (float): Gas height (g/cc).
-        a (float): Cementation exponent.
-        b (float): Saturation exponent.
+        gw (float): Water density (g/cc).
+        ghc (float): Hydrocarbon density (g/cc).
+        a (float): Fitting parameter.
+        b (float): Fitting parameter (negative value).
 
     Returns:
         float: Water saturation from saturation height function.
     """
-    h = fwl - depth
-    shf = (h * (gw - ghc) * .433 / a)**(1 / b) / phit
+    h = (fwl - depth).clip(0)
+    shf = a / ((h * (gw - ghc) * .433)**b * phit)
     return shf
 
 
@@ -382,15 +401,15 @@ def sw_shf_choo(perm, phit, phie, depth, fwl, ift, theta, gw, ghc, b0=0.4):
         fwl (float): Free water level in true vertical depth (ft).
         ift (float): Interfacial tension (dynes/cm).
         theta (float): Wetting angle (degree).
-        gw (float): Gas density (g/cc).
-        ghc (float): Gas height (g/cc).
+        gw (float): Water density (g/cc).
+        ghc (float): Hydrocarbon density (g/cc).
         b0 (float): _description_. Defaults to 0.4.
 
     Returns:
         float: Water saturation from saturation height function.
     """
     swb = 1 - (phie / phit)
-    h = fwl - depth
+    h = (fwl - depth).clip(0)
     pc = h * (gw - ghc) * .433
     shf = 10**((2 * b0 - 1) * np.log10(1 + swb**-1) + np.log10(1 + swb)) / (
         (0.2166 * (pc / (ift * abs(np.cos(np.radians(theta))))) * (
@@ -418,6 +437,7 @@ def autocorrelate_core_depth(df):
               including 'WELL_NAME', 'CORE_ID', 'ORIGINAL_DEPTH', 'DEPTH_CORRECTED',
               and 'DEPTH_SHIFT'.
     """
+    from dtw import dtw
     required_cols = ['WELL_NAME', 'DEPTH', 'PHIT', 'CPORE', 'CPERM', 'CORE_ID']
     for col in required_cols:
         if col not in df.columns:
@@ -488,10 +508,22 @@ def autocorrelate_core_depth(df):
             right_on='DEPTH_CORRECTED',
             how='left'
         )
+
+        # Remove original depths if being corrected
+        ori_core_ids = df_corrected['CORE_ID'].dropna().unique()
+        shifted_core_ids = df_corrected['CORE_ID_SHIFTED'].dropna().unique()
+
+        mask_shifted = df_corrected['CORE_ID'].isin(shifted_core_ids)
+        mask_ori = df_corrected['CORE_ID_SHIFTED'].isin(ori_core_ids)
+
+        df_corrected.loc[mask_shifted, ['CORE_ID', 'CPORE', 'CPERM']] = np.nan
+        df_corrected.loc[mask_ori, ['CORE_ID', 'CPORE', 'CPERM']] = df_corrected.loc[
+            mask_ori, ['CORE_ID_SHIFTED', 'CPORE_SHIFTED', 'CPERM_SHIFTED']].values
+
         return_df = pd.concat([return_df, df_corrected])
 
-    final_summary_df = pd.DataFrame()
     # After the loop, combine all summaries into a single DataFrame
+    final_summary_df = pd.DataFrame()
     if shift_summaries:
         final_summary_df = pd.concat(shift_summaries, ignore_index=True)
 
